__author__ = "Denis V. Shakalo"
__copyright__ = "Copyright (C) 2018 Denis V. Shakalo"
__license__ = """Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/COPYING-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License."""
__version__ = "0.0.2"

import yaml
from kvipset.system import System
from kvipset.vipseterror import VipsetError

class Config:

    def __init__(self, config_file):
        try:
            with open(config_file, 'r') as config:
                config = yaml.load(config)
        except Exception as e:
            raise VipsetError('open '+config_file, e.args, 'openconfig')
        if not config['vips']:
            #raise VipsetError('open '+config_file, 'Vips not found', 'openconfig')
            config['vips'] = dict()
        self._vips = config['vips']
        try:
            if 'interface' in config and System.check_ifname(config['interface']):
                self._ifname = config['interface']
            else:
                self._ifname = System.get_default_ifname()
                if not self._ifname:
                    raise VipsetError('system.check_if_name', 'None', 'getdefaultifname')
        except Exception as e:
            raise VipsetError('system.check_if_name', e.args, 'configgetdefaultifname' )
        try:
            self._real_ip = System.get_primary_ip_address(self._ifname)
        except Exception as e:
            raise VipsetError('system.get_primary_ip_address', e.args, 'configgetrealip' )


    @property
    def vips(self):
        return self._vips

    @property
    def ifname(self):
        return self._ifname

    @property
    def real_ip(self):
        return self._real_ip