"""Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/COPYING-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License."""


import os, sys
from distutils.core import setup
from distutils.command.install import install as _install

def _post_install(dir):
    from subprocess import call
    call([sys.executable, 'systemctl daemon-reload'])

class install(_install):
    def run(self):
        _install.run(self)
        self.execute(_post_install, (self.install_lib,),
                     msg="Reloading systemd. You have to configure, enable and start kvipset service")

long_description = open('README.txt').read()

setup(
    name="kvipset",
    version="0.1.2",
    description='Virtual IP manager for LVS DSR based backends',
    long_description_content_type='text/plain',
    long_description=long_description,
    scripts = ["k-vipset"],
    url='https://github.com/denisshakalo/kvipset',
    author="Denis V. Shakalo",
    author_email="aditor@gmail.com",
    packages=["kvipset"],
    license='Apachev2.0',
    data_files=[('/etc/sysconfig', ['kvipset/configs/kvipset.yaml']),('/etc/systemd/system', ['kvipset/systemd/kvipset.service'])],
    include_package_data=True,
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'Intended Audience :: System Administrators',
        'License :: OSI Approved :: Apache Software License',
        'Operating System :: POSIX :: Linux',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Topic :: System :: Networking',
        'Topic :: System :: Systems Administration',
    ],
    test_suite='tests',
    install_requires=[
        'PyYAML',
    ],
)
